Struct diem_client::SignedTransaction [−][src]
pub struct SignedTransaction { /* fields omitted */ }Expand description
A transaction that has been signed.
A SignedTransaction is a single transaction that can be atomically executed. Clients submit
these to validator nodes, and the validator and executor submits these to the VM.
IMPORTANT: The signature of a SignedTransaction is not guaranteed to be verified. For a
transaction whose signature is statically guaranteed to be verified, see
SignatureCheckedTransaction.
Implementations
pub fn new(
raw_txn: RawTransaction,
public_key: Ed25519PublicKey,
signature: Ed25519Signature
) -> SignedTransaction
pub fn new_multisig(
raw_txn: RawTransaction,
public_key: MultiEd25519PublicKey,
signature: MultiEd25519Signature
) -> SignedTransaction
pub fn new_multi_agent(
raw_txn: RawTransaction,
sender: AccountAuthenticator,
secondary_signer_addresses: Vec<AccountAddress, Global>,
secondary_signers: Vec<AccountAuthenticator, Global>
) -> SignedTransaction
pub fn new_with_authenticator(
raw_txn: RawTransaction,
authenticator: TransactionAuthenticator
) -> SignedTransaction
Checks that the signature of given transaction. Returns Ok(SignatureCheckedTransaction) if
the signature is valid.
Returns the hash when the transaction is commited onchain.